aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--src/surface_integral.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/surface_integral.c b/src/surface_integral.c
index 91f4995..30b3572 100644
--- a/src/surface_integral.c
+++ b/src/surface_integral.c
@@ -216,7 +216,7 @@ void ADMMass_Surface(CCTK_ARGUMENTS)
ds[2] = 0.0;
/* Select the points on the surfaces of the requested cube,
- paying attention not to compute the corners (and the verteces)
+ paying attention not to compute the corners (and the edges)
more than once. */
/* the whole face of the cube */
@@ -225,22 +225,22 @@ void ADMMass_Surface(CCTK_ARGUMENTS)
/* the whole face of the cube */
if (i == x_max_i) ds[0] = oneDY*oneDZ;
/* face, excluding the two corners (and the four verteces) that
were already computed above*/
if ((j == y_min_j) && (i != x_min_i) && (i != x_max_i))
ds[1] = -oneDX*oneDZ;
/* face, excluding the other two corners (and the four verteces)
that were already computed above*/
if ((j == y_max_j) && (i != x_min_i) && (i != x_max_i))
ds[1] = oneDX*oneDZ;
/* face, excluding all corners (and verteces), since they were
already computed above */
if ((k == z_min_k) && (j != y_min_j) && (i != x_min_i) && (j != y_max_j) && (i != x_max_i))
ds[2] = -oneDX*oneDY;
/* face, excluding all corners (and verteces), since they were
already computed above */
if ((k == z_max_k) && (j != y_min_j) && (i != x_min_i) &&
(j != y_max_j) && (i != x_max_i))
@@ -225,22 +225,22 @@ void ADMMass_Surface(CCTK_ARGUMENTS)
/* the whole face of the cube */
if (i == x_max_i) ds[0] = oneDY*oneDZ;
- /* face, excluding the two corners (and the four verteces) that
+ /* face, excluding the two corners (and the four edges) that
were already computed above*/
if ((j == y_min_j) && (i != x_min_i) && (i != x_max_i))
@@ -225,22 +225,22 @@ void ADMMass_Surface(CCTK_ARGUMENTS)
if ((j == y_min_j) && (i != x_min_i) && (i != x_max_i))
ds[1] = -oneDX*oneDZ;
- /* face, excluding the other two corners (and the four verteces)
+ /* face, excluding the other two corners (and the four edges)
that were already computed above*/
if ((j == y_max_j) && (i != x_min_i) && (i != x_max_i))
@@ -225,22 +225,22 @@ void ADMMass_Surface(CCTK_ARGUMENTS)
if ((j == y_max_j) && (i != x_min_i) && (i != x_max_i))
ds[1] = oneDX*oneDZ;
- /* face, excluding all corners (and verteces), since they were
+ /* face, excluding all corners (and edges), since they were
already computed above */
if ((k == z_min_k) && (j != y_min_j) && (i != x_min_i) && (j != y_max_j) && (i != x_max_i))
@@ -225,22 +225,22 @@ void ADMMass_Surface(CCTK_ARGUMENTS)
if ((k == z_min_k) && (j != y_min_j) && (i != x_min_i) && (j != y_max_j) && (i != x_max_i))
ds[2] = -oneDX*oneDY;
- /* face, excluding all corners (and verteces), since they were
+ /* face, excluding all corners (and edges), since they were
already computed above */
if ((k == z_max_k) && (j != y_min_j) && (i != x_min_i) &&